.. :changelog:

0.4.0 (2021-02-15)
++++++++++++++++++

- Updated packaging and installation issues
- Updated CI and Python version testing

0.3.1 (2018-01-08)
++++++++++++++++++

- Fixed issue where george would not compile with GCC<4.9 because of a
  compiler bug
- Fixed bug when re-using HODLR factorizations

0.3.0 (2017-07-12)
++++++++++++++++++

- New modeling protocol for parameter fitting
- Rewritten HODLR algorithm - more stable and better performance
- New interface for "easily" implementing new kernel functions

pre-0.3
+++++++

- This project has had a long and tumultuous history
